# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_util/util.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18th2_grpc_util/util.proto\x12\x04util\x1a\x1cth2_grpc_common/common.proto\"+\n\x12\x43omparisonSettings\x12\x15\n\rignore_fields\x18\x01 \x03(\t\"\x88\x01\n\x1e\x43ompareFilterVsMessagesRequest\x12\x1e\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0e.MessageFilter\x12\x1a\n\x08messages\x18\x02 \x03(\x0b\x32\x08.Message\x12*\n\x08settings\x18\x03 \x01(\x0b\x32\x18.util.ComparisonSettings\"a\n\x1f\x43ompareFilterVsMessagesResponse\x12>\n\x12\x63omparison_results\x18\x01 \x03(\x0b\x32\".util.CompareFilterVsMessageResult\"p\n\x1c\x43ompareFilterVsMessageResult\x12\x1e\n\nmessage_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12\x30\n\x11\x63omparison_result\x18\x02 \x01(\x0b\x32\x15.util.ComparisonEntry\"]\n\x1e\x43ompareMessageVsMessageRequest\x12;\n\x10\x63omparison_tasks\x18\x01 \x03(\x0b\x32!.util.CompareMessageVsMessageTask\"b\n\x1f\x43ompareMessageVsMessageResponse\x12?\n\x12\x63omparison_results\x18\x01 \x03(\x0b\x32#.util.CompareMessageVsMessageResult\"|\n\x1b\x43ompareMessageVsMessageTask\x12\x17\n\x05\x66irst\x18\x01 \x01(\x0b\x32\x08.Message\x12\x18\n\x06second\x18\x02 \x01(\x0b\x32\x08.Message\x12*\n\x08settings\x18\x03 \x01(\x0b\x32\x18.util.ComparisonSettings\"\x9e\x01\n\x1d\x43ompareMessageVsMessageResult\x12$\n\x10\x66irst_message_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12%\n\x11second_message_id\x18\x02 \x01(\x0b\x32\n.MessageID\x12\x30\n\x11\x63omparison_result\x18\x03 \x01(\x0b\x32\x15.util.ComparisonEntry\"\xb4\x02\n\x0f\x43omparisonEntry\x12\'\n\x04type\x18\x01 \x01(\x0e\x32\x19.util.ComparisonEntryType\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.util.ComparisonEntryStatus\x12\r\n\x05\x66irst\x18\x03 \x01(\t\x12\x0e\n\x06second\x18\x04 \x01(\t\x12#\n\toperation\x18\x05 \x01(\x0e\x32\x10.FilterOperation\x12\x0e\n\x06is_key\x18\x06 \x01(\x08\x12\x31\n\x06\x66ields\x18\x07 \x03(\x0b\x32!.util.ComparisonEntry.FieldsEntry\x1a\x44\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.util.ComparisonEntry:\x02\x38\x01*0\n\x13\x43omparisonEntryType\x12\t\n\x05\x46IELD\x10\x00\x12\x0e\n\nCOLLECTION\x10\x01*7\n\x15\x43omparisonEntryStatus\x12\x06\n\x02NA\x10\x00\x12\n\n\x06PASSED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x32\xe3\x01\n\x11MessageComparator\x12\x66\n\x17\x63ompareFilterVsMessages\x12$.util.CompareFilterVsMessagesRequest\x1a%.util.CompareFilterVsMessagesResponse\x12\x66\n\x17\x63ompareMessageVsMessage\x12$.util.CompareMessageVsMessageRequest\x1a%.util.CompareMessageVsMessageResponseB\x1e\n\x1a\x63om.exactpro.th2.util.grpcP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'th2_grpc_util.util_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.exactpro.th2.util.grpcP\001'
  _COMPARISONENTRY_FIELDSENTRY._options = None
  _COMPARISONENTRY_FIELDSENTRY._serialized_options = b'8\001'
  _COMPARISONENTRYTYPE._serialized_start=1254
  _COMPARISONENTRYTYPE._serialized_end=1302
  _COMPARISONENTRYSTATUS._serialized_start=1304
  _COMPARISONENTRYSTATUS._serialized_end=1359
  _COMPARISONSETTINGS._serialized_start=64
  _COMPARISONSETTINGS._serialized_end=107
  _COMPAREFILTERVSMESSAGESREQUEST._serialized_start=110
  _COMPAREFILTERVSMESSAGESREQUEST._serialized_end=246
  _COMPAREFILTERVSMESSAGESRESPONSE._serialized_start=248
  _COMPAREFILTERVSMESSAGESRESPONSE._serialized_end=345
  _COMPAREFILTERVSMESSAGERESULT._serialized_start=347
  _COMPAREFILTERVSMESSAGERESULT._serialized_end=459
  _COMPAREMESSAGEVSMESSAGEREQUEST._serialized_start=461
  _COMPAREMESSAGEVSMESSAGEREQUEST._serialized_end=554
  _COMPAREMESSAGEVSMESSAGERESPONSE._serialized_start=556
  _COMPAREMESSAGEVSMESSAGERESPONSE._serialized_end=654
  _COMPAREMESSAGEVSMESSAGETASK._serialized_start=656
  _COMPAREMESSAGEVSMESSAGETASK._serialized_end=780
  _COMPAREMESSAGEVSMESSAGERESULT._serialized_start=783
  _COMPAREMESSAGEVSMESSAGERESULT._serialized_end=941
  _COMPARISONENTRY._serialized_start=944
  _COMPARISONENTRY._serialized_end=1252
  _COMPARISONENTRY_FIELDSENTRY._serialized_start=1184
  _COMPARISONENTRY_FIELDSENTRY._serialized_end=1252
  _MESSAGECOMPARATOR._serialized_start=1362
  _MESSAGECOMPARATOR._serialized_end=1589
# @@protoc_insertion_point(module_scope)
